@@ -16,13 +16,17 @@ A logging module which handles ZServer access log messages.
 
 This depends on Vinay Sajip's PEP 282 logging module.
 """
-import logging
-from zLOG.BaseLogger import BaseLogger
+
+from ZServer.BaseLogger import BaseLogger
+
 
 class AccessLogger(BaseLogger):
-    logger = logging.getLogger('access')
+
+    def __init__(self):
+        BaseLogger.__init__(self, 'access')
+
     def log(self, message):
-        if not self.logger.handlers: # dont log if we have no handlers
+        if not self.logger.handlers: # don't log if we have no handlers
             return
         if message.endswith('\n'):
             message = message[:-1]
